%global major_version 5.4
# Normally, this is the same as version, but... not always.
%global test_version 5.4.8
# If you are incrementing major_version, enable bootstrapping and adjust accordingly.
# Version should be the latest prior build. If you don't do this, RPM will break and
# everything will grind to a halt.
%global bootstrap 0
%global bootstrap_major_version 5.3
%global bootstrap_version 5.3.6

%define compatname %mklibname %{name} %{bootstrap_major_version}

%define major %{major_version}
%define libname %mklibname %{name} %{major}
%define develname %mklibname %{name} -d
%define staticname %mklibname %{name} -d -s

Name:           lua
Version:        5.4.8
Release:        %mkrel 1
Summary:        Powerful light-weight programming language
License:        MIT
Group:          Development/Other
URL:            https://www.lua.org/
Source0:        https://www.lua.org/ftp/lua-%{version}.tar.gz
# copied from doc/readme.html on 2014-07-18
Source1:        mit.txt
%if 0%{?bootstrap}
Source2:        https://www.lua.org/ftp/lua-%{bootstrap_version}.tar.gz
%endif
Source3:        https://www.lua.org/tests/lua-%{test_version}-tests.tar.gz
# multilib
Source4:        luaconf.h
Patch0:         lua-5.4.0-beta-autotoolize.patch
Patch1:         lua-5.4.6-idsize.patch
Patch3:         lua-5.2.2-configure-linux.patch
Patch4:         lua-5.3.0-configure-compat-module.patch
Patch5:         lua-5.3.0-autotoolize.patch
Patch6:         lua-5.3.5-luac-shared-link-fix.patch

# Mga patches
Patch100:       lua-5.2.1-dynlib.patch

BuildRequires:  automake autoconf libtool readline-devel ncurses-devel
BuildRequires:  make
Provides:       lua%{major_version} = %{version}-%{release}
Conflicts:      lua5.1 < 5.1.5-18

%description
Lua is a powerful light-weight programming language designed for
extending applications. Lua is also frequently used as a
general-purpose, stand-alone language. Lua is free software.
Lua combines simple procedural syntax with powerful data description
constructs based on associative arrays and extensible semantics. Lua
is dynamically typed, interpreted from bytecodes, and has automatic
memory management with garbage collection, making it ideal for
configuration, scripting, and rapid prototyping.

%package -n %{develname}
Summary:        Development files for %{name}
Group:          Development/Other
Requires:       %{name}%{?_isa}  = %{version}-%{release}
Requires:       %{libname} = %{version}-%{release}
# The RPM related dependencies bring nothing to a non-RPM Lua developer
# But we want them when packages BuildRequire lua-devel
Requires:       lua-rpm-macros
Requires:       pkgconfig
Provides:       lua-devel = %{version}-%{release}
Provides:       lua%{lua_version}-devel = %{version}-%{release}
Obsoletes:      %{_lib}lua5.3-devel < 5.4
Conflicts:      %{_lib}lua5.1-devel < 5.1.5-18

%description -n %{develname}
This package contains development files for %{name}.

%package -n %{libname}
Summary:        Libraries for %{name}
Group:          System/Libraries
Provides:       lua(abi) = %{major_version}

%description -n %{libname}
This package contains the shared libraries for %{name}.

%package -n %{staticname}
Summary:        Static library for %{name}
Group:          Development/Other
Requires:       %{develname} = %{version}-%{release}
Obsoletes:      %{_lib}lua5.3-static-devel < 5.4

%description -n %{staticname}
This package contains the static version of liblua for %{name}.

%package -n %{compatname}
Summary:        Libraries for %{name} %{bootstrap_major_version}
Group:          System/Libraries
Provides:       lua(abi) = %{bootstrap_major_version}
Obsoletes:      lua%{bootstrap_major_version} < %{major_version}
Provides:       lua%{bootstrap_major_version} = %{bootstrap_version}

%description -n %{compatname}
This package contains the shared libraries for %{name} %{bootstrap_major_version}.

%prep
%if 0%{?bootstrap}
%setup -q -a 2 -a 3 -n %{name}-%{version}
%else
%setup -q -a 3
%endif
cp %{SOURCE1} .
mv src/luaconf.h src/luaconf.h.template.in
%patch -P0 -p1 -E -z .autoxxx
%patch -P1 -p1 -z .idsize
%patch -P3 -p1 -z .configure-linux

# Put proper version in configure.ac, patch0 hardcodes 5.3.0
sed -i '/AC_INIT/s|5.[0-9].[0-9]|%{version}|g' configure.ac

%if 0%{?bootstrap}
pushd lua-%{bootstrap_version}/
%patch -P6 -p1 -b .luac-shared-link-fix
%patch -P100 -p1 -b .dynlib
sed -i -e "s|\$(V)|%{bootstrap_major_version}|g" src/Makefile
popd
%endif

%build
autoreconf -fi
%configure --with-readline --with-compat-module

# Autotools give me a headache sometimes.
sed -i 's|@pkgdatadir@|%{_datadir}|g' src/luaconf.h.template

%make_build LIBS="-lm -ldl"

%if 0%{?bootstrap}
pushd lua-%{bootstrap_version}
sed -i 's/-lncurses/-lncursesw/g' */Makefile*
# (tv) enable compat module (fix building rpm with lua-5.2):
%make_build linux CFLAGS="%{optflags} -fPIC -DLUA_USE_LINUX -DLUA_COMPAT_MODULE -DLUA_COMPAT_BITLIB -DLUA_COMPAT_APIINTCASTS"
popd
%endif

%check
cd ./lua-%{test_version}-tests/

# Dont skip the fully portable or ram-hungry tests:
# sed -i.orig -e '
#     /attrib.lua/d;
#     /files.lua/d;
#     /db.lua/d;
#     /errors.lua/d;
#     ' all.lua
# LD_LIBRARY_PATH=%%{buildroot}%%{_libdir} %%{buildroot}%%{_bindir}/lua all.lua

# Removing tests that fail under mock/koji
sed -i.orig -e '
    /db.lua/d;
    /errors.lua/d;
    ' all.lua
LD_LIBRARY_PATH=%{buildroot}%{_libdir} %{buildroot}%{_bindir}/lua -e"_U=true" all.lua

%install
%make_install

mkdir -p %{buildroot}%{_libdir}/lua/%{major_version}
mkdir -p %{buildroot}%{_datadir}/lua/%{major_version}

# Rename luaconf.h to luaconf-<arch>.h to avoid file conflicts on
# multilib systems and install luaconf.h wrapper
mv %{buildroot}%{_includedir}/luaconf.h %{buildroot}%{_includedir}/luaconf-%{_arch}.h
install -p -m 644 %{SOURCE4} %{buildroot}%{_includedir}/luaconf.h

%if 0%{?bootstrap}
pushd lua-%{bootstrap_version}
install -Dpm755 src/liblua.so.%{bootstrap_major_version} %{buildroot}%{_libdir}/
mkdir -p %{buildroot}%{_libdir}/lua/%{bootstrap_major_version}
mkdir -p %{buildroot}%{_datadir}/lua/%{bootstrap_major_version}
popd
%endif

# add compat pkgconfig files
ln -s lua.pc %{buildroot}%{_libdir}/pkgconfig/lua%{major_version}.pc
ln -s lua.pc %{buildroot}%{_libdir}/pkgconfig/lua-%{major_version}.pc

# TODO: Remove after mga9
# Needed with %%ghost and scriptlets to silent update-alternatives warnings when updating:
# warning: %postun(lua5.3-5.3.6-3.mga9.x86_64) scriptlet failed, exit status 2
# ERROR: 'script' failed for lua5.3-5.3.6-3.mga9.x86_64
touch %{buildroot}%{_bindir}/lua5.{2,3}

%triggerun -- lua < 5.4
if [[ -e  %{_localstatedir}/lib/alternatives/lua ]]; then
   %{_sbindir}/update-alternatives --remove-all lua 2> /dev/null ||:
fi
touch %{_bindir}/lua5.2

%triggerun -- lua5.3 < 5.4
if [[ -e  %{_localstatedir}/lib/alternatives/lua ]]; then
   %{_sbindir}/update-alternatives --remove-all lua 2> /dev/null ||:
fi
touch %{_bindir}/lua5.3

%triggerpostun -- lua < 5.4
if [[ -f %{_bindir}/lua5.2 ]]; then
 rm -rf %{_bindir}/lua5.2
fi

%triggerpostun -- lua5.3 < 5.4
if [[ -f %{_bindir}/lua5.3 ]]; then
 rm -rf %{_bindir}/lua5.3
fi

%files
%{!?_licensedir:%global license %%doc}
%license mit.txt

%doc README doc/*.html doc/*.css doc/*.gif doc/*.png
%{_bindir}/lua
%ghost %{_bindir}/lua5.?
%{_bindir}/luac
%{_mandir}/man1/lua*.1*

%files -n %{libname}
%dir %{_libdir}/lua/
%dir %{_libdir}/lua/%{major_version}/
%{_libdir}/liblua-%{major_version}.so
%dir %{_datadir}/lua/
%dir %{_datadir}/lua/%{major_version}/

%if 0%{?bootstrap}
%files -n %{compatname}
%dir %{_libdir}/lua/%{bootstrap_major_version}/
%{_libdir}/liblua.so.%{bootstrap_major_version}
%dir %{_datadir}/lua/%{bootstrap_major_version}/
%endif

%files -n %{develname}
%{_includedir}/l*.h
%{_includedir}/l*.hpp
%{_libdir}/liblua.so
%{_libdir}/pkgconfig/*.pc

%files -n %{staticname}
%{_libdir}/*.a


%changelog
* Wed Jun 04 2025 daviddavid <daviddavid> 5.4.8-1.mga10
+ Revision: 2188156
- new version: 5.4.8

* Sat Apr 12 2025 daviddavid <daviddavid> 5.4.7-1.mga10
+ Revision: 2174829
- new version: 5.4.7
- add some compat pkgconfig files

* Fri Apr 05 2024 wally <wally> 5.4.6-2.mga10
+ Revision: 2054662
- basesystem rebuild for i686

* Wed Mar 27 2024 wally <wally> 5.4.6-1.mga10
+ Revision: 2052811
- new version 5.4.6

* Tue Dec 13 2022 daviddavid <daviddavid> 5.4.4-3.mga9
+ Revision: 1921761
- Add patch for http://lua-users.org/lists/lua-l/2022-02/msg00112.html (#2111138)
  * fixes lsyncd build

* Sat Sep 03 2022 wally <wally> 5.4.4-2.mga9
+ Revision: 1883613
- add upstream bug fixes 1-5 and 7, including fixes for CVE-2022-28805 and CVE-2022-33099 (mga#30016)

* Sun Apr 17 2022 wally <wally> 5.4.4-1.mga9
+ Revision: 1851037
- new version 5.4.4

* Fri Mar 18 2022 umeabot <umeabot> 5.4.3-7.mga9
+ Revision: 1797854
- Mageia 9 Mass Rebuild

* Sat Apr 17 2021 wally <wally> 5.4.3-6.mga9
+ Revision: 1716242
- add more fixes for updating lua from mga8

* Thu Apr 15 2021 wally <wally> 5.4.3-5.mga9
+ Revision: 1715914
- fix updating lua from mga8 (mga#28773)

* Sun Apr 04 2021 wally <wally> 5.4.3-4.mga9
+ Revision: 1713077
- fix static devel pkg requires

* Sat Apr 03 2021 wally <wally> 5.4.3-3.mga9
+ Revision: 1713026
- disable bootstrap build and drop lua 5.3 compat lib
- conflict with old lua 5.1 devel pkg also providing liblua.so

* Fri Apr 02 2021 wally <wally> 5.4.3-2.mga9
+ Revision: 1712806
- obsolete old lua5.3 static devel pkg

* Fri Apr 02 2021 wally <wally> 5.4.3-1.mga9
+ Revision: 1712736
- new version 5.4.3

* Fri Apr 02 2021 wally <wally> 5.4.2-3.mga9
+ Revision: 1712732
- fix update from older lua versions

* Fri Apr 02 2021 wally <wally> 5.4.2-2.mga9
+ Revision: 1712662
- fix version in lua.pc

* Fri Apr 02 2021 wally <wally> 5.4.2-1.mga9
+ Revision: 1712651
- new version 5.4.2 (sync with Fedora where appropriate)
- build compat library for lua5.3 to bootstrap new lua major version (modified from Fedora to suit for our lib name)
- drop alternatives support

* Sun Mar 28 2021 wally <wally> 5.2.4-10.mga9
+ Revision: 1711499
- require lua-rpm-macros with devel pkg

* Sun Mar 28 2021 wally <wally> 5.2.4-9.mga9
+ Revision: 1711327
- add lua(abi) provides

* Sat Mar 27 2021 wally <wally> 5.2.4-8.mga9
+ Revision: 1711210
- add versioned lua5.2 provides

* Wed Sep 02 2020 ns80 <ns80> 5.2.4-7.mga8
+ Revision: 1620892
- add patch for CVE-2020-24370 (mga#27213)

* Fri Apr 17 2020 ovitters <ovitters> 5.2.4-6.mga8
+ Revision: 1568261
- have lua require the library

* Tue Feb 18 2020 umeabot <umeabot> 5.2.4-5.mga8
+ Revision: 1542186
- Mageia 8 Mass Rebuild

* Sat Jan 04 2020 luigiwalser <luigiwalser> 5.2.4-4.mga8
+ Revision: 1475983
- rebuild for readline

* Fri Oct 05 2018 umeabot <umeabot> 5.2.4-3.mga7
+ Revision: 1317846
- Mageia 7 Mass Rebuild
+ kekepower <kekepower>
- Use new make macros

* Tue Jan 02 2018 wally <wally> 5.2.4-2.mga7
+ Revision: 1189323
- rebuild for new readline

* Wed Sep 07 2016 luigiwalser <luigiwalser> 5.2.4-1.mga6
+ Revision: 1050407
- 5.2.4

* Tue Apr 05 2016 pterjan <pterjan> 5.2.3-9.mga6
+ Revision: 998787
- Fix file list

* Fri Mar 04 2016 luigiwalser <luigiwalser> 5.2.3-8.mga6
+ Revision: 985779
- rebuild lua 5.2
- restore lua 5.2 as lua

* Fri Aug 21 2015 tmb <tmb> 5.2.3-7.mga6
+ Revision: 867620
- rebuild for new gcc

* Mon Oct 20 2014 tmb <tmb> 5.2.3-6.mga5
+ Revision: 792175
- require update-alternatives for post(un) scripts

* Wed Oct 15 2014 umeabot <umeabot> 5.2.3-5.mga5
+ Revision: 739870
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 5.2.3-4.mga5
+ Revision: 682024
- Mageia 5 Mass Rebuild

* Mon Jun 30 2014 tv <tv> 5.2.3-3.mga5
+ Revision: 641667
- enable compat module (thus fixing building rpm with lua-5.2)
- simplify patch
+ colin <colin>
- Own the /usr/{share,lib[64]}/lua/5.2 dirs.

* Sun Mar 02 2014 luigiwalser <luigiwalser> 5.2.3-1.mga5
+ Revision: 598630
- 5.2.3

* Sat Oct 19 2013 umeabot <umeabot> 5.2.2-2.mga4
+ Revision: 522814
- Mageia 4 Mass Rebuild

* Thu Mar 28 2013 guillomovitch <guillomovitch> 5.2.2-1.mga3
+ Revision: 405991
- new version

* Sat Jan 12 2013 umeabot <umeabot> 5.2.1-2.mga3
+ Revision: 359041
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Sat Sep 08 2012 luigiwalser <luigiwalser> 5.2.1-1.mga3
+ Revision: 289798
- 5.2.1
+ fwang <fwang>
- drop old taball

* Sat Jun 02 2012 blue_prawn <blue_prawn> 5.2.0-1.mga3
+ Revision: 253448
- sync tarball lua-5.2.0.tar.gz
- update to last version lua-5.2.0

* Sat Jun 02 2012 blue_prawn <blue_prawn> 5.1.4-11.mga3
+ Revision: 253361
- the .o file of the interactive interpreter should not be included in the .so lib

* Fri Mar 09 2012 tv <tv> 5.1.4-10.mga2
+ Revision: 221977
- link with libncursesw instead of libncurses else rpm is linked with
  both libncursesw & libncurses and text installer crashes (mga#4724)

* Sun Jan 09 2011 shikamaru <shikamaru> 5.1.4-9.mga1
+ Revision: 3362
- Spec cleaning
- remove old obsoletes
- remove ldconfig in post (handled in filetriggers)
- imported package lua


* Fri Dec 03 2010 Oden Eriksson <oeriksson@mandriva.com> 5.1.4-9mdv2011.0
+ Revision: 606426
- rebuild

* Mon Mar 15 2010 Rémy Clouard <shikamaru@mandriva.org> 5.1.4-8mdv2010.1
+ Revision: 520626
- rebuild

* Wed Sep 02 2009 Christophe Fergeau <cfergeau@mandriva.com> 5.1.4-7mdv2010.0
+ Revision: 426015
- rebuild

* Wed Feb 25 2009 Thierry Vignaud <tv@mandriva.org> 5.1.4-6mdv2009.1
+ Revision: 344654
- rebuild for new libreadline in order to unbreak cooker

* Sat Jan 24 2009 Per Øyvind Karlsen <peroyvind@mandriva.org> 5.1.4-5mdv2009.1
+ Revision: 333184
- previous patch was broken, remove libdir completely since library resides in
  standard location and doesn't need to get passed to linker anyways..

* Mon Dec 29 2008 Jérôme Soyer <saispo@mandriva.org> 5.1.4-4mdv2009.1
+ Revision: 320762
- Bump Release
- Add patch for fixing 64bit issue

  + Per Øyvind Karlsen <peroyvind@mandriva.org>
    - remove -L{libdir} from lua.pc so that -L/usr/lib won't be passed to ldflags
      (very annoying on x86_64 which will give a lot of warnings about skipping
      32 bit libraries under /ur/lib..)

* Fri Sep 19 2008 Guillaume Rousse <guillomovitch@mandriva.org> 5.1.4-2mdv2009.0
+ Revision: 285916
- ensure devel package requires main package

* Tue Sep 09 2008 Emmanuel Andry <eandry@mandriva.org> 5.1.4-1mdv2009.0
+ Revision: 283044
- New version
- drop P1 (merged upstream)

* Wed Aug 06 2008 Thierry Vignaud <tv@mandriva.org> 5.1.3-5mdv2009.0
+ Revision: 265034
- rebuild early 2009.0 package (before pixel changes)

  + Pixel <pixel@mandriva.com>
    - do not call ldconfig in %%post/%%postun, it is now handled by filetriggers

* Thu Jun 05 2008 Tomasz Pawel Gajc <tpg@mandriva.org> 5.1.3-4mdv2009.0
+ Revision: 215155
- Patch1: add upstream patch

* Thu Jun 05 2008 Tomasz Pawel Gajc <tpg@mandriva.org> 5.1.3-3mdv2009.0
+ Revision: 215152
- rebuild for new gcc-4.3

* Mon Feb 18 2008 Thierry Vignaud <tv@mandriva.org> 5.1.3-2mdv2008.1
+ Revision: 170970
- rebuild
- fix "foobar is blabla" summary (=> "blabla") so that it looks nice in rpmdrake

* Mon Feb 11 2008 Tomasz Pawel Gajc <tpg@mandriva.org> 5.1.3-1mdv2008.1
+ Revision: 165019
- fix summaries and descriptions
- fix lua.pc
- new version

* Tue Jan 15 2008 Thierry Vignaud <tv@mandriva.org> 5.1.2-6mdv2008.1
+ Revision: 152880
- rebuild
- rebuild
- kill re-definition of %%buildroot on Pixel's request

  + Olivier Blin <oblin@mandriva.com>
    - restore BuildRoot

* Sun Aug 05 2007 Anssi Hannula <anssi@mandriva.org> 5.1.2-4mdv2008.0
+ Revision: 59119
- make liblua.so a proper devel symlink instead of a copy

* Mon Jul 16 2007 Funda Wang <fwang@mandriva.org> 5.1.2-3mdv2008.0
+ Revision: 52568
- Obsoletes old static devel name

* Wed Jun 20 2007 Tomasz Pawel Gajc <tpg@mandriva.org> 5.1.2-2mdv2008.0
+ Revision: 41814
- new devel library policy
- spec file clean

* Sat May 19 2007 Tomasz Pawel Gajc <tpg@mandriva.org> 5.1.2-1mdv2008.0
+ Revision: 28430
- new version
- drop P1
- make use of %%{major}
- spec file clean


* Tue Mar 06 2007 Olivier Thauvin <nanardon@mandriva.org> 5.1.1-9mdv2007.0
+ Revision: 133768
- obsoletes liblua5 to avoid files conflicts

* Mon Nov 13 2006 Pascal Terjan <pterjan@mandriva.org> 5.1.1-8mdv2007.0
+ Revision: 83555
- ship lua.pc

* Fri Aug 25 2006 Nicolas Lécureuil <neoclust@mandriva.org> 5.1.1-7mdv2007.0
+ Revision: 57833
- Increase release
- Fix group

  + Gaëtan Lehmann <glehmann@mandriva.org>
    - add alternative for lua and luac
    - small spec cleanup

* Sun Aug 20 2006 Olivier Thauvin <nanardon@mandriva.org> 5.1.1-5mdv2007.0
+ Revision: 56856
- replace major from 5 to 5.1 for lua5.0 cohabitation

* Sat Aug 19 2006 Thierry Vignaud <tvignaud@mandriva.com> 5.1.1-4mdv2007.0
+ Revision: 56793
- fix build on x86_64

* Fri Aug 18 2006 Olivier Thauvin <nanardon@mandriva.org> 5.1.1-3mdv2007.0
+ Revision: 56554
- reprovide liblua and its -devel
- add patch to enable .so building

  + Götz Waschk <waschk@mandriva.org>
    - fix buildrequires

* Sun Aug 13 2006 Olivier Thauvin <nanardon@mandriva.org> 5.1.1-2mdv2007.0
+ Revision: 55708
- release package
- provide also liblua-devel
- handle the name change -devel to -devel-static

  + Götz Waschk <waschk@mandriva.org>
    - fix buildrequires

* Fri Aug 11 2006 Helio Chissini de Castro <helio@mandriva.com> 5.1.1-1mdv2007.0
+ Revision: 55509
- New upstream version 5.1.1
- Lua now is just static, as decided by developers. This package will solve the
  conflicts with old lua on main and new wrong package on contrib
- import lua-5.0.2-9mdk

* Fri Oct 07 2005 Götz Waschk <waschk@mandriva.org> 5.0.2-9mdk
- fix packaging bugs 16461 and 19006

* Mon Oct 03 2005 Pascal Terjan <pterjan@mandriva.org> 5.0.2-8mdk
- add SONAME to the libs so that other package don't want -devel (P3)

* Sat Jul 09 2005 Thierry Vignaud <tvignaud@mandrakesoft.com> 5.0.2-7mdk
- fix provides for x86_64

* Wed Apr 13 2005 Olivier Thauvin <nanardon@mandrake.org> 5.0.2-6mdk
- avoid postun exit 1 (thanks Eskild Hustvedt && Daniel Le Berre)

* Tue Apr 12 2005 Olivier Thauvin <nanardon@mandrake.org> 5.0.2-5mdk
- add -fPIC on x86_64
- fix lib location

* Sat Mar 12 2005 Gaetan Lehmann <gaetan.lehmann@jouy.inra.fr> 5.0.2-4mdk
- fix update-alternatives (#14460)

* Thu Mar 10 2005 Per Øyvind Karlsen <peroyvind@linux-mandrake.com> 5.0.2-3mdk
- fix ownership of files (fixes #14458)
- fix libuse- cosmetics
- compile with optimizations

* Mon Aug 30 2004 Thierry Vignaud <tvignaud@mandrakesoft.com> 5.0.2-2mdk
- fix .so links

* Wed May 05 2004 Lenny Cartier <lenny@mandrakesoft.com> 5.0.2-1mdk
- from Andre Nathan <andre@digirati.com.br>

